﻿using Central.Control.WebApi.Cache;
using Central.Control.WebApi.DbEntity;
using Central.Control.WebApi.EFDbContext;
using Central.Control.WebApi.IOC;
using Central.Control.WebApi.Service.Interface;
using System;
using System.Linq;
using System.Web.Http;
using System.Web.Http.Controllers;

namespace Central.Control.WebApi.Filter
{
    /// <summary>
    /// 
    /// </summary>
    public class CenterControlAuthorize: AuthorizeAttribute
    {

        /// <summary>
        /// check if is authorized
        /// </summary>
        /// <param name="httpContext"></param>
        /// <returns></returns>
        protected override bool IsAuthorized(HttpActionContext httpContext)
        {
            var _cacheHelper = IOCService.GetFromFac<ICacheHelper>();
            var _dbContext = IOCService.GetFromFac<IDbContext>();

            string token = string.Empty;
            if (httpContext.Request.Headers.Contains("token"))
            {
                token = httpContext.Request.Headers.GetValues("token")?.FirstOrDefault();
            }

            bool isAuthorized = false;
            if (!string.IsNullOrWhiteSpace(token))
            {
                var session = _cacheHelper.Get<SYS_LoginSession>(token);
                if (session == null)
                {
                    // 再去库里查一遍看看，防止缓存直接挂
                    session = _dbContext.Set<SYS_LoginSession>().FirstOrDefault(p => p.Token == token);
                    if (session != null && session.Expiration > DateTime.Now)
                    {
                        _cacheHelper.SetByNotExpired(session.UserName, session.Token);// 这一份存一个凭证
                        _cacheHelper.SetByNotExpired(session.Token, session);// 这一份存真正的登录信息
                    }
                }
                if (session != null && session.Expiration > DateTime.Now)
                {
                    // 登录认证成功
                    isAuthorized = true;
                }
            }
            return isAuthorized;
        }

    }
}